==> RsSmbv-4.80.0.9-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Eutra_/Dl_/Drs_/Cell_/Pattern.py <==
from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pattern:
	"""Pattern commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pattern", core, parent)

	def set(self, eutra_drs_pattern: List[int], channel=repcap.Channel.Default) -> None:
		"""[SOURce<HW>]:BB:EUTRa:DL:DRS:CELL<CH>:PATTern \n
		Defines the subframes in that DRS is transmitted for up to 20 DRS occasions. \n
			:param eutra_drs_pattern: No help available
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')"""
		param = Conversions.list_to_csv_str(eutra_drs_pattern)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:DRS:CELL{channel_cmd_val}:PATTern {param}')

	def get(self, channel=repcap.Channel.Default) -> List[int]:
		"""[SOURce<HW>]:BB:EUTRa:DL:DRS:CELL<CH>:PATTern \n
		Defines the subframes in that DRS is transmitted for up to 20 DRS occasions. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: eutra_drs_pattern: No help available"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_bin_or_ascii_int_list(f'SOURce<HwInstance>:BB:EUTRa:DL:DRS:CELL{channel_cmd_val}:PATTern?')
		return response

==> RsSmbv-4.80.0.12-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Eutra_/Dl_/Drs_/Cell_/Pattern.py <==
from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pattern:
	"""Pattern commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pattern", core, parent)

	def set(self, eutra_drs_pattern: List[int], channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:DRS:CELL<CH>:PATTern \n
		Snippet: driver.source.bb.eutra.dl.drs.cell.pattern.set(eutra_drs_pattern = [1, 2, 3], channel = repcap.Channel.Default) \n
		Defines the subframes in that DRS is transmitted for up to 20 DRS occasions. \n
			:param eutra_drs_pattern: No help available
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')"""
		param = Conversions.list_to_csv_str(eutra_drs_pattern)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:DRS:CELL{channel_cmd_val}:PATTern {param}')

	def get(self, channel=repcap.Channel.Default) -> List[int]:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:DRS:CELL<CH>:PATTern \n
		Snippet: value: List[int] = driver.source.bb.eutra.dl.drs.cell.pattern.get(channel = repcap.Channel.Default) \n
		Defines the subframes in that DRS is transmitted for up to 20 DRS occasions. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: eutra_drs_pattern: No help available"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_bin_or_ascii_int_list(f'SOURce<HwInstance>:BB:EUTRa:DL:DRS:CELL{channel_cmd_val}:PATTern?')
		return response
